@@ -10,5 +10,5 @@
   toset <- !(names(op.ic) %in% names(op))
   if (any(toset)) options(op.ic[toset])
   
-  invisible()
+  invisible(NULL)
 }
\ No newline at end of file
